import argparse
from aiohttp import web
from rupload.app import create_app


def parse_args():
    parser = argparse.ArgumentParser(description="Start the file upload server.")
    parser.add_argument(
        "--hostname", type=str, default="127.0.0.1", help="The hostname for the server."
    )
    parser.add_argument(
        "--port", type=int, default=8081, help="The port to bind the server to."
    )
    parser.add_argument(
        "--upload_folder",
        type=str,
        default="uploads",
        help="Directory to store uploaded files.",
    )
    parser.add_argument(
        "--upload_url",
        type=str,
        default="/uploads/",
        help="HTTP(S) URL where the server will serve the uploaded files.",
    )
    parser.add_argument(
        "--max_file_size",
        type=int,
        default=50 * 1024 * 1024,
        help="Maximum file size in bytes (default is 50MB).",
    )
    parser.add_argument(
        "--upload_folder_quota",
        type=int,
        default=10 * 1024 * 1024 * 1024,
        help="Quata upload folder in bytes (default is 10GB).",
    )
    return parser.parse_args()


def main():
    args = parse_args()
    app = create_app(
        upload_url=args.upload_url,
        upload_path=args.upload_folder,
        max_file_size=args.max_file_size,
        upload_folder_quota=args.upload_folder_quota,
    )
    web.run_app(app, host=args.hostname, port=args.port)


if __name__ == "__main__":
    main()
